==> cscec5b-fbxt-impl-3.0.0-20210201.105805-148-sources.jar: com/ejianc/business/fbxt/odd/controller/OddInfoController.java <==
package com.ejianc.business.fbxt.odd.controller;

import java.io.Serializable;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import java.util.List;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.fbxt.odd.bean.OddInfoEntity;
import com.ejianc.business.fbxt.odd.service.IOddInfoService;
import com.ejianc.business.fbxt.odd.vo.OddInfoVO;

/**
 * 零星用工申请单实体
 * 
 * @author generator
 * 
 */
@Controller
@RequestMapping("oddInfo")
public class OddInfoController implements Serializable {
	private static final long serialVersionUID = 1L;
	
    private Logger logger = LoggerFactory.getLogger(this.getClass());
    
    @Autowired
    private IOddInfoService service; 
    
    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<OddInfoVO> saveOrUpdate(@RequestBody OddInfoVO saveorUpdateVO) {
    	OddInfoEntity entity = BeanMapper.map(saveorUpdateVO, OddInfoEntity.class);
    	service.saveOrUpdate(entity, false);
    	OddInfoVO vo = BeanMapper.map(entity, OddInfoVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }
    
    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<OddInfoVO> queryDetail(Long id) {
    	OddInfoEntity entity = service.selectById(id);
    	OddInfoVO vo = BeanMapper.map(entity, OddInfoVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }
    
    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<OddInfoVO> vos) {
        service.removeByIds(vos.stream().map(OddInfoVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }
    
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<OddInfoVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        
        IPage<OddInfoEntity> page = service.queryPage(param,false);
        IPage<OddInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), OddInfoVO.class));
        
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

}

==> cscec5b-fbxt-impl-3.0.1-20251014.091841-203-sources.jar: com/ejianc/business/fbxt/odd/controller/OddInfoController.java <==
package com.ejianc.business.fbxt.odd.controller;

import java.io.Serializable;

import com.ejianc.business.fbxt.odd.service.IOddService;
import com.ejianc.business.fbxt.odd.vo.OddDetailVO;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import java.util.List;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.fbxt.odd.bean.OddInfoEntity;
import com.ejianc.business.fbxt.odd.service.IOddInfoService;
import com.ejianc.business.fbxt.odd.vo.OddInfoVO;

/**
 * 零星用工申请单实体
 * 
 * @author generator
 * 
 */
@Controller
@RequestMapping("oddInfo")
public class OddInfoController implements Serializable {
	private static final long serialVersionUID = 1L;
	
    private Logger logger = LoggerFactory.getLogger(this.getClass());
    
    @Autowired
    private IOddInfoService service; 

    @Autowired
    private IOddService oddservice;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<OddInfoVO> saveOrUpdate(@RequestBody OddInfoVO saveorUpdateVO) {
    	OddInfoEntity entity = BeanMapper.map(saveorUpdateVO, OddInfoEntity.class);
    	service.saveOrUpdate(entity, false);

        OddDetailVO redirect = oddservice.queryRedirect(entity.getId());
        if (redirect != null && redirect.getZkcontractName()!=null) {     // 转扣合同
            entity.setZkcontract(redirect.getZkcontractName());
        } else {
            entity.setZkcontract("");
        }
        if (redirect != null && redirect.getRedirectcorp()!=null) {       // 转扣单位
            entity.setZkcorpname(redirect.getRedirectcorp());
        } else {
            entity.setZkcorpname("");
        }
        service.saveOrUpdate(entity, false);

        OddInfoVO vo = BeanMapper.map(entity, OddInfoVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }
    
    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<OddInfoVO> queryDetail(Long id) {
    	OddInfoEntity entity = service.selectById(id);
    	OddInfoVO vo = BeanMapper.map(entity, OddInfoVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }
    
    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<OddInfoVO> vos) {
        service.removeByIds(vos.stream().map(OddInfoVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }
    
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<OddInfoVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        
        IPage<OddInfoEntity> page = service.queryPage(param,false);
        IPage<OddInfoVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), OddInfoVO.class));
        
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

}
